@@ -46,7 +46,6 @@ DJVU read code taken fromdvutxt.c:
 
 #include <iostream>
 
-//#include <iconv.h>
 
 #include <QFile>
 #include <QXmlStreamReader>
@@ -455,7 +454,6 @@ CCharsetMagic::CCharsetMagic()
   std::vector<CSignaturesList*>::iterator it2 = std::find(signatures.begin(), signatures.end(), koi8r);
   std::swap (*it1, *it2);
 
-
 //  qDebug() << "signatures.size: " << signatures.size();
 /*
   int ku = signatures.indexOf (koi8u);
@@ -612,10 +610,8 @@ bool CTioFB2::load (const QString &fname)
          QString tag_name = xml.qualifiedName().toString().toLower();
 
          if (xml.isStartElement())
-            {
              if (tag_name == ts)
                 tt = true;
-            }
 
          if (xml.isEndElement())
             {
@@ -627,6 +623,9 @@ bool CTioFB2::load (const QString &fname)
 
              if (tag_name == "section")
                  data.append ("\n");
+
+             if (tag_name == "empty-line")
+                 data.append ("\n");
             }
 
          if (tt && xml.isCharacters())
@@ -855,6 +854,9 @@ CTioPDF::CTioPDF()
 }
 
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+
+
 bool CTioPDF::load (const QString &fname)
 {
   Poppler::Document *d = Poppler::Document::load (fname);
@@ -891,6 +893,50 @@ bool CTioPDF::load (const QString &fname)
   return true;
 }
 
+#endif
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0) && QT_VERSION < QT_VERSION_CHECK(7, 0, 0))
+
+
+bool CTioPDF::load (const QString &fname)
+{
+  std::unique_ptr<Poppler::Document> d = Poppler::Document::load (fname);
+
+  if (! d)
+     return false;
+
+  if (d->isLocked())
+     {
+    //  delete d;
+      return false;
+     }
+
+
+  int pages_count = d->numPages();
+
+  for (int i = 0; i < pages_count; i++)
+      {
+      std::unique_ptr<Poppler::Page> p = d->page (i);
+
+       std::vector<std::unique_ptr<Poppler::TextBox> > tb = p->textList();
+
+       for (int j = 0; j < tb.size(); j++)
+           {
+            data += tb[j]->text();
+            //if (tb[j]->hasSpaceAfter())
+            data += " ";
+
+           // delete tb[j];
+           }
+      }
+
+ // delete d;
+  return true;
+}
+
+#endif
+
+
 #endif
 
 
@@ -997,12 +1043,12 @@ bool CTioEpub::load (const QString &fname)
 {
   data.clear();
 
-  QStringList html_files;
-
   CZipper zipper;
   if (! zipper.read_as_utf8 (fname, "META-INF/container.xml"))
        return false;
 
+  QStringList html_files;
+
   QString opf_fname;
   QString opf_dir;
 
@@ -1068,125 +1114,3 @@ QStringList CTioHandler::get_supported_exts()
   l.append ("txt");
   return l;
 }
-
-/*
-
-QString cp1251_to_utf16 (char *inbuf, int len)
-{
-  QString r;
-  char *outbuf = new char [len * 2];
-
-  iconv_t cd = iconv_open ("UTF-16","CP1251");
-  size_t inbytesleft;
-  size_t outbytesleft;
-
-
-  size_t s = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
-
-  QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
-
-  delete [] outbuf;
-
-  iconv_close (cd);
-  return r;
-}
-
-
-
-void CIconvCharsetConverter::load_charsets()
-{
-  charsets.prepend ("UTF-8");
-  charsets.prepend ("UTF-16");
-  charsets.prepend ("CP1251");
-  charsets.prepend ("KOI8-R");
-  charsets.prepend ("KOI8-U");
-  charsets.prepend ("DOS866");
-
-}
-
-
-  https://code.woboq.org/qt5/qtbase/src/corelib/codecs/qiconvcodec.cpp.html
-
-    QByteArray ba(outBytesLeft, Qt::Uninitialized);
-    char *outBytes = ba.data();
-
-  */
-/*
-QString CIconvCharsetConverter::to_utf16 (const QString &enc_from, char *inbuf, int len)
-{
-  QString r;
-  //char *outbuf = new char [len * 2 + 2]; //last 2 is bom
-  const char *inBytes = inbuf;
-
-  iconv_t cd = iconv_open ("UTF-8", enc_from.toLatin1().data());
-  size_t inbytesleft = len;
-  size_t outbytesleft = len * 4 + 2;
-
-  QByteArray ba (outbytesleft, Qt::Uninitialized);
-  char *outbuf = ba.data();
-
-  size_t total = outbytesleft;
-
-  qDebug() << "inbytesleft: " << inbytesleft;
-  qDebug() << "outbytesleft: " << outbytesleft;
-
-  while (inbytesleft > 0)
-        {
-         size_t e = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
-
-//         qDebug() << "e:" <<e;
-
-        }
-
-
-  //if (e != -1)
-    //r = QString::fromLatin1 (outbuf, len * 2);
-   //   r = QString::fromUtf8 (outbuf, total - outbytesleft);
-
-
-  qDebug() << "inbytesleft: " << inbytesleft;
-  qDebug() << "outbytesleft: " << outbytesleft;
-
-    //QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
-
-   //[static]QString QString::fromUtf8(const char * str, int size = -1)
-
-
-  iconv_close (cd);
-
-  //delete [] outbuf;
-
-  return QString (ba);
-}
-
-
-QStringList charsets_for_locale (const QString &loc)
-{
-  QStringList l;
-
-  return l;
-}
-*/
-/*
-char* CIconvCharsetConverter::from_utf_16 (const QString &enc_to, const QString &data)
-{
-  char *outbuf = new char [len * 2];
-
-  iconv_t cd = iconv_open ("UTF-16", enc_to.toLatin1().data());
-  size_t inbytesleft = len;
-  size_t outbytesleft = len * 2;
-
-
-  size_t e = iconv (cd, &inbuf, &inbytesleft, &outbuf, &outbytesleft);
-  if (e != -1)
-    r = QString::fromLatin1 (outbuf, len * 2);
-
-    //QByteArray ba = QByteArray::fromRawData (outbuf, len * 2);
-
-   //[static]QString QString::fromUtf8(const char * str, int size = -1)
-
-
-  iconv_close (cd);
-  return outbuf;
-}
-*/
